@@ -8,7 +8,8 @@
 # -p installation path of Postgres
 # -j JDBC driver path
 # -m install (install pgpool-II and use that for tests) / noinstall : Default install
-# -s unix socket directory 
+# -s unix socket directory
+# -c test pgpool using sample scripts and config files
 # -d start pgpool with debug option
 
 dir=`pwd`
@@ -92,7 +93,12 @@ function export_env_vars
  	fi
 	
 	echo "using pgpool-II at "$PGPOOL_PATH
+
+	export PGPOOL_VERSION=`$PGPOOL_PATH/bin/pgpool --version 2>&1`
+
 	export PGPOOL_INSTALL_DIR=$PGPOOL_PATH
+	# where to look for pgpool.conf.sample files.
+	export PGPOOLDIR=$PGPOOL_INSTALL_DIR/etc
 
 	PGPOOLLIB=${PGPOOL_INSTALL_DIR}/lib
 	if [ -z "$LD_LIBRARY_PATH" ];then
@@ -116,7 +122,8 @@ function print_info
 	echo ${CBLUE}"*************************"${CNORM}
 
 	echo "REGRESSION MODE          : "${CBLUE}$MODE${CNORM}
-	echo "PGPOOL-II                : "${CBLUE}$PGPOOL_PATH${CNORM}
+	echo "Pgpool-II version        : "${CBLUE}$PGPOOL_VERSION${CNORM}
+	echo "Pgpool-II install path   : "${CBLUE}$PGPOOL_PATH${CNORM}
 	echo "PostgreSQL bin           : "${CBLUE}$PGBIN${CNORM}
 	echo "PostgreSQL Major version : "${CBLUE}$PGVERSION${CNORM}
 	echo "pgbench                  : "${CBLUE}$PGBENCH_PATH${CNORM}
@@ -136,6 +143,7 @@ function print_usage
 	printf "  -j   FILE                Postgres jdbc jar file path\n" >&2
 	printf "  -s   DIRECTORY           unix socket directory\n" >&2
 	printf "  -t   TIMEOUT             timeout value for each test (sec)\n" >&2
+	printf "  -c                       test pgpool using sample scripts and config files\n" >&2
 	printf "  -d                       start pgpool with debug option\n" >&2
 	printf "  -?                       print this help and then exit\n\n" >&2
 	printf "Please read the README for details on adding new tests\n" >&2
@@ -144,7 +152,7 @@ function print_usage
 
 trap "echo ; exit 0" SIGINT SIGQUIT
 
-while getopts "p:m:i:j:b:s:t:d?" OPTION
+while getopts "p:m:i:j:b:s:t:cd?" OPTION
 do
   case $OPTION in
     p)  PG_INSTALL_DIR="$OPTARG";;
@@ -154,6 +162,7 @@ do
     b)  PGBENCH_PATH="$OPTARG";;
     s)  PGSOCKET_DIR="$OPTARG";;
     t)  TIMEOUT="$OPTARG";;
+    c)  export TEST_SAMPLES="true";;
     d)  export PGPOOLDEBUG="true";;
     ?)  print_usage
         exit 2;;
